# legaldata (alpha version)

[![pypi Version](https://img.shields.io/pypi/v/legaldata.svg?logo=pypi)](https://pypi.org/project/legaldata/)
![Latest Tag](https://img.shields.io/github/v/tag/dylanhogg/legaldata)
![Depenencies](https://img.shields.io/librariesio/github/dylanhogg/legaldata)

A package for getting getting Australian legal data from various sources with cache support.


### Install from PyPi
```
pip install legaldata
```

Legal Data is distributed under the MIT license.
